Description Usage Format Source Examples
Line transect survey data from the bowhead whale survey reported in Rekdal et al. (2015).
1 |
A data frame of line transect data suitable for analysis with package Distance.
Rekdal, S.L., Hansen, R.G., Borchers, D., Bachmann, L., Laidre, K.L., Wiig, O., Nielsen, N.H., Fossette, S., Tervo, O. and Heide-Jorgensen, M.P., 2015. Trends in bowhead whales in West Greenland: Aerial surveys vs. genetic capture-recapture analyses. Marine Mammal Science, 31(1), pp.133-154.
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.