Description Usage Arguments Details Value
Calculates the negative log-likelihood for models M0, Mt, Mb, Mtb.
1 | loglik.Mtb(pars, chmat, prevcap = NULL, timecov = NULL)
|
pars |
Parameter vector with the correct number of parameters in the correct order (see Details). |
chmat |
Binary capture history matrix, with one row per individual detected and one column per capture occasion. |
prevcap |
Binary matrix of same size as |
timecov |
Matrix of same size as |
The function decides which model to use on the basis of which of prevcap and
timecov are null. It assumes that pars has the appropriate number of parameters
for the model, and in the appropriate order, as follows:
'M0' prevcap and timecov both NULL: pars must be
(log(N),qlogis(p)).
'Mt' prevcap NULL, timecov not: pars must be
(log(N),qlogis(p1)...qlogis(pK)), where there are K occasions.
'Mb' prevcap not NUL, timecov is NULL: pars must be
(log(N),qlogis(p),log(b)), where log(b) is the change in log-odds due to
previous capture.
'Mtb' Neither prevcap nor timecov are NULL: pars must be
(log(N),qlogis(p1)...qlogis(pK),log(b)), where there are K occasions and
log(b) is the change in log-odds due to previous capture.
The negative log-likelihood for the appropriate model.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.